pub struct LodUploadReceipt {
pub node: NodeId,
pub generation: u64,
pub host_bytes: u64,
pub upload_bytes: u64,
pub gpu_bytes: u64,
pub evicted: Vec<NodeId>,
pub peak_host_bytes: u64,
}Expand description
Exact receipt for a host lease followed by caller-performed GPU upload.
Fields
node: NodeIdUploaded node.
generation: u64Plan/frame generation.
host_bytes: u64Decoded host bytes held until upload completion.
upload_bytes: u64Caller-declared bytes transferred to GPU.
gpu_bytes: u64Caller-declared resident GPU bytes.
evicted: Vec<NodeId>Nodes evicted to fit.
peak_host_bytes: u64Peak host lease bytes observed by the shared tracker.